==> haskell-jose-0.8.5-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 jose
version:              0.8.5
visibility:           public
id:                   jose-0.8.5-4LIrQfFWuXcBVvl3MrgXBI
key:                  jose-0.8.5-4LIrQfFWuXcBVvl3MrgXBI
license:              Apache-2.0
copyright:            Copyright (C) 2013-2018  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-jose
synopsis:
    Javascript Object Signing and Encryption and JSON Web Token library

description:

    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.

    The JSON Web Signature (JWS; RFC 7515) implementation is complete.

    EdDSA signatures (RFC 8037) are supported (Ed25519 only).

    JWK Thumbprint (RFC 7638) is supported.

    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.

    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.

category:             Cryptography
abi:                  3b87b708fe843d67511388a8c4371531
exposed:              True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT

hidden-modules:
    Crypto.JOSE.TH Crypto.JOSE.Types.Internal Crypto.JOSE.Types.Orphans

import-dirs:          /usr/lib/ghc-9.0.1/site-local/jose-0.8.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/jose-0.8.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/jose-0.8.5
hs-libraries:         HSjose-0.8.5-4LIrQfFWuXcBVvl3MrgXBI
depends:
    QuickCheck-2.14.2-Ah3Pa5Fl9gvF5c5fvpDPwz
    aeson-1.5.6.0-Hu48mgwBrEQKjw91bueUbm
    attoparsec-0.14.1-EcyJzfZhZzx4rFmzSXlwR7 base-4.15.0.0
    base64-bytestring-1.2.1.0-3y8bVgj4ClGFIgxpge9J2V
    bytestring-0.10.12.1 concise-0.1.0.1-HFvtZfbW14IEB2yDcxr2Mi
    containers-0.6.4.1 cryptonite-0.29-Ael7JaBLzwtAWHfQYnAVOO
    lens-5.0.1-rlrBG3eUIE9ghmFG9oii1
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    monad-time-0.3.1.0-4tLFe4CV0BOLalyGkEzbQ3 mtl-2.2.2
    network-uri-2.6.4.1-DyGoFFEZQ5VEtmFaj1kRtK
    quickcheck-instances-0.3.25.2-4wri9UVxH9yLV7iImnmaUP
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj template-haskell-2.17.0.0
    text-1.2.4.1 time-1.9.3
    unordered-containers-0.2.14.0-7LMDP5QPSZY4o6Vs5H6SAe
    vector-0.12.3.1-7avVqi4S14u4vwRbDqmIKr
    x509-1.7.5-DBNkn0viXiYGzD8hayOZw9

haddock-interfaces:   /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html:         /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose-0.8.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-jose.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 jose
version:              0.8.5
visibility:           public
id:                   jose-0.8.5-AKEah0rObe4KxHooz1zoe7
key:                  jose-0.8.5-AKEah0rObe4KxHooz1zoe7
license:              Apache-2.0
copyright:            Copyright (C) 2013-2018  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-jose
synopsis:
    Javascript Object Signing and Encryption and JSON Web Token library

description:

    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.

    The JSON Web Signature (JWS; RFC 7515) implementation is complete.

    EdDSA signatures (RFC 8037) are supported (Ed25519 only).

    JWK Thumbprint (RFC 7638) is supported.

    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.

    The __ECDSA implementation is vulnerable to timing attacks__ and
    should only be used for verification.

category:             Cryptography
abi:                  42c678875224ec63d4ee340444a0cdee
exposed:              True
exposed-modules:
    Crypto.JOSE Crypto.JOSE.AESKW Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
    Crypto.JOSE.JWA.JWK Crypto.JOSE.JWA.JWS Crypto.JOSE.JWE
    Crypto.JOSE.JWK Crypto.JOSE.JWK.Store Crypto.JOSE.JWS
    Crypto.JOSE.Types Crypto.JWT

hidden-modules:
    Crypto.JOSE.TH Crypto.JOSE.Types.Internal Crypto.JOSE.Types.Orphans

import-dirs:          /usr/lib/ghc-9.0.1/site-local/jose-0.8.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/jose-0.8.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/jose-0.8.5
hs-libraries:         HSjose-0.8.5-AKEah0rObe4KxHooz1zoe7
depends:
    QuickCheck-2.14.2-4fFmALdK9KzLSVxePLHYEq
    aeson-1.5.6.0-5xJqgJM7Xo44Ry8m4HB8YT
    attoparsec-0.14.1-2Lwpa9GUrZtgMvbVSsTwE base-4.15.0.0
    base64-bytestring-1.2.1.0-JsO9e8VuajE8G17lKXfVPj
    bytestring-0.10.12.1 concise-0.1.0.1-LbyRbNRpH4F2LNpJtzqkNH
    containers-0.6.4.1 cryptonite-0.29-5rSENL0PHSf9WUZRJG7DOz
    lens-5.0.1-60ifKnBVxc97Z5mKEPHeAT
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    monad-time-0.3.1.0-4tLFe4CV0BOLalyGkEzbQ3 mtl-2.2.2
    network-uri-2.6.4.1-9p35oSDSrRH5LnXL8JxE48
    quickcheck-instances-0.3.25.2-E22s5kcmDoG27ll1TkA04
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj template-haskell-2.17.0.0
    text-1.2.4.1 time-1.9.3
    unordered-containers-0.2.14.0-7mG6qiSFB7aBJ8f89E596e
    vector-0.12.3.1-EZShNBWDQ9s3G4ursgcoB7
    x509-1.7.5-GLpywcUFqFi168eMYVQ2WY

haddock-interfaces:   /usr/share/doc/haskell-jose/html/jose.haddock
haddock-html:         /usr/share/doc/haskell-jose/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
